CCL: /home/chisarie/Documents/lsst_ccl/CCL/src/ccl_core.c File Reference

CCL

Functions | Variables
ccl_core.c File Reference
`#include "ccl_core.h"`
`#include "ccl_neutrinos.h"`
`#include "ccl_utils.h"`
`#include "ccl_constants.h"`
`#include <stdlib.h>`
`#include <math.h>`
`#include <stdio.h>`
`#include <string.h>`
`#include "gsl/gsl_errno.h"`
`#include "gsl/gsl_odeiv.h"`
`#include "gsl/gsl_spline.h"`
`#include "gsl/gsl_integration.h"`
`#include "ccl_params.h"`
`#include "ccl_error.h"`

## Functions
void | ccl_cosmology_read_config (void)
ccl_cosmology * | ccl_cosmology_create (ccl_parameters params, ccl_configuration config)
ccl_cosmology * | ccl_cosmology_create_with_params (double Omega_c, double Omega_b, double Omega_k, double N_nu_rel, double N_nu_mass, double M_nu, double w0, double wa, double h, double norm_pk, double n_s, int nz_mgrowth, double *zarr_mgrowth, double *dfarr_mgrowth, ccl_configuration config, int *status)
ccl_cosmology * | ccl_cosmology_create_with_lcdm_params (double Omega_c, double Omega_b, double Omega_k, double h, double norm_pk, double n_s, ccl_configuration config, int *status)
void | ccl_parameters_fill_initial (ccl_parameters *params, int *status)
ccl_parameters | ccl_parameters_create (double Omega_c, double Omega_b, double Omega_k, double N_nu_rel, double N_nu_mass, double mnu, double w0, double wa, double h, double norm_pk, double n_s, int nz_mgrowth, double *zarr_mgrowth, double *dfarr_mgrowth, int *status)
ccl_parameters | ccl_parameters_create_flat_lcdm (double Omega_c, double Omega_b, double h, double norm_pk, double n_s, int *status)
ccl_parameters | ccl_parameters_create_flat_lcdm_nu (double Omega_c, double Omega_b, double h, double norm_pk, double n_s, double N_nu_rel, double N_nu_mass, double mnu, int *status)
ccl_parameters | ccl_parameters_create_lcdm (double Omega_c, double Omega_b, double Omega_k, double h, double norm_pk, double n_s, int *status)
ccl_parameters | ccl_parameters_create_lcdm_nu (double Omega_c, double Omega_b, double Omega_k, double h, double norm_pk, double n_s, double N_nu_rel, double N_nu_mass, double mnu, int *status)
ccl_parameters | ccl_parameters_create_flat_wcdm (double Omega_c, double Omega_b, double w0, double h, double norm_pk, double n_s, int *status)
ccl_parameters | ccl_parameters_create_flat_wcdm_nu (double Omega_c, double Omega_b, double w0, double h, double norm_pk, double n_s, double N_nu_rel, double N_nu_mass, double mnu, int *status)
ccl_parameters | ccl_parameters_create_flat_wacdm (double Omega_c, double Omega_b, double w0, double wa, double h, double norm_pk, double n_s, int *status)
ccl_parameters | ccl_parameters_create_flat_wacdm_nu (double Omega_c, double Omega_b, double w0, double wa, double h, double norm_pk, double n_s, double N_nu_rel, double N_nu_mass, double mnu, int *status)
void | ccl_data_free (ccl_data *data)
void | ccl_cosmology_free (ccl_cosmology *cosmo)

## Variables
const ccl_configuration | default_config = {ccl_boltzmann_class, ccl_halofit, ccl_tinker10}
ccl_spline_params * | ccl_splines

## Function Documentation

## ◆ ccl_cosmology_create()

ccl_cosmology* ccl_cosmology_create | ( | ccl_parameters | params,
|  | ccl_configuration | config
| ) |  |

## ◆ ccl_cosmology_create_with_lcdm_params()

ccl_cosmology* ccl_cosmology_create_with_lcdm_params | ( | double | Omega_c,
|  | double | Omega_b,
|  | double | Omega_k,
|  | double | h,
|  | double | norm_pk,
|  | double | n_s,
|  | ccl_configuration | config,
|  | int * | status
| ) |  |

## ◆ ccl_cosmology_create_with_params()

ccl_cosmology* ccl_cosmology_create_with_params | ( | double | Omega_c,
|  | double | Omega_b,
|  | double | Omega_k,
|  | double | N_nu_rel,
|  | double | N_nu_mass,
|  | double | M_nu,
|  | double | w0,
|  | double | wa,
|  | double | h,
|  | double | norm_pk,
|  | double | n_s,
|  | int | nz_mgrowth,
|  | double * | zarr_mgrowth,
|  | double * | dfarr_mgrowth,
|  | ccl_configuration | config,
|  | int * | status
| ) |  |

## ◆ ccl_cosmology_free()

void ccl_cosmology_free | ( | ccl_cosmology * | cosmo | ) |

Free a cosmology struct

Parameters

  cosmo | Cosmological parameters

Returns
  void

## ◆ ccl_cosmology_read_config()

void ccl_cosmology_read_config | ( | void |  | ) |

## ◆ ccl_data_free()

void ccl_data_free | ( | ccl_data * | data | ) |

## ◆ ccl_parameters_create()

ccl_parameters ccl_parameters_create | ( | double | Omega_c,
|  | double | Omega_b,
|  | double | Omega_k,
|  | double | N_nu_rel,
|  | double | N_nu_mass,
|  | double | mnu,
|  | double | w0,
|  | double | wa,
|  | double | h,
|  | double | norm_pk,
|  | double | n_s,
|  | int | nz_mgrowth,
|  | double * | zarr_mgrowth,
|  | double * | dfarr_mgrowth,
|  | int * | status
| ) |  |

Create a cosmology

Parameters

  Omega_c | Omega_c
  Omega_b | Omega_b
  Omega_k | Omega_k
  N_nu_rel | Number of relativisitic species
  N_nu_mass | N_nu_mass
  mnu | neutrino mass
  w0 | Dark energy EoS parameter
  wa | Dark energy EoS parameter
  h | Hubble constant in units of 100 km/s/Mpc
  norm_pk | the normalization of the power spectrum, either A_s or sigma_8
  n_s | the power-law index of the power spectrum
  nz_mgrowth | the number of redshifts where the modified growth is provided
  zarr_mgrowth | the array of redshifts where the modified growth is provided
  dfarr_mgrowth | the modified growth function vector provided
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.c

Returns
  void

## ◆ ccl_parameters_create_flat_lcdm()

ccl_parameters ccl_parameters_create_flat_lcdm | ( | double | Omega_c,
|  | double | Omega_b,
|  | double | h,
|  | double | norm_pk,
|  | double | n_s,
|  | int * | status
| ) |  |

Create a flat LCDM cosmology

Parameters

  Omega_c | Omega_c
  Omega_b | Omega_b
  h | Hubble constant in units of 100 km/s/Mpc
  norm_pk | the normalization of the power spectrum, either A_s or sigma_8
  n_s | the power-law index of the power spectrum
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.c

Returns
  void

## ◆ ccl_parameters_create_flat_lcdm_nu()

ccl_parameters ccl_parameters_create_flat_lcdm_nu | ( | double | Omega_c,
|  | double | Omega_b,
|  | double | h,
|  | double | norm_pk,
|  | double | n_s,
|  | double | N_nu_rel,
|  | double | N_nu_mass,
|  | double | mnu,
|  | int * | status
| ) |  |

## ◆ ccl_parameters_create_flat_wacdm()

ccl_parameters ccl_parameters_create_flat_wacdm | ( | double | Omega_c,
|  | double | Omega_b,
|  | double | w0,
|  | double | wa,
|  | double | h,
|  | double | norm_pk,
|  | double | n_s,
|  | int * | status
| ) |  |

Create a flat waCDM cosmology

Parameters

  Omega_c | Omega_c
  Omega_b | Omega_b
  w0 | Dark energy EoS parameter
  wa | Dark energy EoS parameter
  h | Hubble constant in units of 100 km/s/Mpc
  norm_pk | the normalization of the power spectrum, either A_s or sigma_8
  n_s | the power-law index of the power spectrum
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.c

Returns
  void

## ◆ ccl_parameters_create_flat_wacdm_nu()

ccl_parameters ccl_parameters_create_flat_wacdm_nu | ( | double | Omega_c,
|  | double | Omega_b,
|  | double | w0,
|  | double | wa,
|  | double | h,
|  | double | norm_pk,
|  | double | n_s,
|  | double | N_nu_rel,
|  | double | N_nu_mass,
|  | double | mnu,
|  | int * | status
| ) |  |

## ◆ ccl_parameters_create_flat_wcdm()

ccl_parameters ccl_parameters_create_flat_wcdm | ( | double | Omega_c,
|  | double | Omega_b,
|  | double | w0,
|  | double | h,
|  | double | norm_pk,
|  | double | n_s,
|  | int * | status
| ) |  |

Create a flat wCDM cosmology

Parameters

  Omega_c | Omega_c
  Omega_b | Omega_b
  w0 | Dark energy EoS parameter
  h | Hubble constant in units of 100 km/s/Mpc
  norm_pk | the normalization of the power spectrum, either A_s or sigma_8
  n_s | the power-law index of the power spectrum
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.c

Returns
  void

## ◆ ccl_parameters_create_flat_wcdm_nu()

ccl_parameters ccl_parameters_create_flat_wcdm_nu | ( | double | Omega_c,
|  | double | Omega_b,
|  | double | w0,
|  | double | h,
|  | double | norm_pk,
|  | double | n_s,
|  | double | N_nu_rel,
|  | double | N_nu_mass,
|  | double | mnu,
|  | int * | status
| ) |  |

## ◆ ccl_parameters_create_lcdm()

ccl_parameters ccl_parameters_create_lcdm | ( | double | Omega_c,
|  | double | Omega_b,
|  | double | Omega_k,
|  | double | h,
|  | double | norm_pk,
|  | double | n_s,
|  | int * | status
| ) |  |

Create an LCDM cosmology with curvature

Parameters

  Omega_c | Omega_c
  Omega_b | Omega_b
  Omega_k | Omega_k
  w0 | Dark energy EoS parameter
  wa | Dark energy EoS parameter
  h | Hubble constant in units of 100 km/s/Mpc
  norm_pk | the normalization of the power spectrum, either A_s or sigma_8
  n_s | the power-law index of the power spectrum
  status | Status flag. 0 if there are no errors, nonzero otherwise. For specific cases see documentation for ccl_error.c

Returns
  void

## ◆ ccl_parameters_create_lcdm_nu()

ccl_parameters ccl_parameters_create_lcdm_nu | ( | double | Omega_c,
|  | double | Omega_b,
|  | double | Omega_k,
|  | double | h,
|  | double | norm_pk,
|  | double | n_s,
|  | double | N_nu_rel,
|  | double | N_nu_mass,
|  | double | mnu,
|  | int * | status
| ) |  |

## ◆ ccl_parameters_fill_initial()

void ccl_parameters_fill_initial | ( | ccl_parameters * | params,
|  | int * | status
| ) |  |

## Variable Documentation

## ◆ ccl_splines

ccl_spline_params* ccl_splines

## ◆ default_config

const ccl_configuration default_config = {ccl_boltzmann_class, ccl_halofit, ccl_tinker10}

The default configuration object In the default configuration, defined in ccl_core.c CCL runs with: default_config = {ccl_boltzmann_class, ccl_halofit, ccl_tinker10}